@@ -1,4 +1,5 @@
 use super::common::utils::consts::{ZELLIJ_CONFIG_DIR_ENV, ZELLIJ_CONFIG_FILE_ENV};
+use crate::common::input::options::Options;
 use serde::{Deserialize, Serialize};
 use std::path::PathBuf;
 use structopt::StructOpt;
@@ -36,21 +37,20 @@ pub struct CliArgs {
 #[derive(Debug, StructOpt, Clone, Serialize, Deserialize)]
 pub enum ConfigCli {
     /// Change the behaviour of zellij
-    #[structopt(name = "option")]
-    Config {
-        /// Disables loading of configuration file at default location
-        #[structopt(long)]
-        clean: bool,
-    },
+    #[structopt(name = "options")]
+    Options(Options),
 
     #[structopt(name = "generate-completion")]
     GenerateCompletion { shell: String },
 
     #[structopt(name = "setup")]
     Setup {
-        /// Disables loading of configuration file at default location
         /// Dump the default configuration file to stdout
         #[structopt(long)]
         dump_config: bool,
+        /// Disables loading of configuration file at default location,
+        /// loads the defaults that zellij ships with
+        #[structopt(long)]
+        clean: bool,
     },
 }
