@@ -4,13 +4,17 @@ use std::{
     fmt::{self, Debug, Formatter},
 };
 
+use vte::{Params, Perform};
+
 const TABSTOP_WIDTH: usize = 8; // TODO: is this always right?
 const SCROLL_BACK: usize = 10_000;
 
+use crate::utils::consts::VERSION;
 use crate::utils::logging::debug_log_to_file;
+use crate::utils::shared::version_number;
 
 use crate::panes::terminal_character::{
-    CharacterStyles, CharsetIndex, Cursor, StandardCharset, TerminalCharacter,
+    CharacterStyles, CharsetIndex, Cursor, CursorShape, StandardCharset, TerminalCharacter,
     EMPTY_TERMINAL_CHARACTER,
 };
 
@@ -175,6 +179,7 @@ pub struct Grid {
     saved_cursor_position: Option<Cursor>,
     scroll_region: Option<(usize, usize)>,
     active_charset: CharsetIndex,
+    preceding_char: Option<TerminalCharacter>,
     pub should_render: bool,
     pub cursor_key_mode: bool, // DECCKM - when set, cursor keys should send ANSI direction codes (eg. "OD") instead of the arrow keys (eg. "[D")
     pub erasure_mode: bool,    // ERM
@@ -183,6 +188,7 @@ pub struct Grid {
     pub clear_viewport_before_rendering: bool,
     pub width: usize,
     pub height: usize,
+    pub pending_messages_to_pty: Vec<Vec<u8>>,
 }
 
 impl Debug for Grid {
@@ -208,6 +214,7 @@ impl Grid {
             cursor: Cursor::new(0, 0),
             saved_cursor_position: None,
             scroll_region: None,
+            preceding_char: None,
             width: columns,
             height: rows,
             should_render: true,
@@ -218,6 +225,7 @@ impl Grid {
             alternative_lines_above_viewport_and_cursor: None,
             clear_viewport_before_rendering: false,
             active_charset: Default::default(),
+            pending_messages_to_pty: vec![],
         }
     }
     pub fn contains_widechar(&self) -> bool {
@@ -243,6 +251,26 @@ impl Grid {
         empty_character.styles = styles;
         self.pad_current_line_until(self.cursor.x);
     }
+    pub fn move_to_previous_tabstop(&mut self) {
+        let mut previous_tabstop = None;
+        for tabstop in self.horizontal_tabstops.iter() {
+            if *tabstop >= self.cursor.x {
+                break;
+            }
+            previous_tabstop = Some(tabstop);
+        }
+        match previous_tabstop {
+            Some(tabstop) => {
+                self.cursor.x = *tabstop;
+            }
+            None => {
+                self.cursor.x = 0;
+            }
+        }
+    }
+    pub fn cursor_shape(&self) -> CursorShape {
+        self.cursor.get_shape()
+    }
     fn set_horizontal_tabstop(&mut self) {
         self.horizontal_tabstops.insert(self.cursor.x);
     }
@@ -811,7 +839,8 @@ impl Grid {
     pub fn show_cursor(&mut self) {
         self.cursor.is_hidden = false;
     }
-    pub fn set_scroll_region(&mut self, top_line_index: usize, bottom_line_index: usize) {
+    pub fn set_scroll_region(&mut self, top_line_index: usize, bottom_line_index: Option<usize>) {
+        let bottom_line_index = bottom_line_index.unwrap_or(self.height);
         self.scroll_region = Some((top_line_index, bottom_line_index));
     }
     pub fn clear_scroll_region(&mut self) {
@@ -922,10 +951,14 @@ impl Grid {
         self.active_charset = Default::default();
         self.erasure_mode = false;
         self.disable_linewrap = false;
+        self.cursor.change_shape(CursorShape::Block);
+    }
+    fn set_preceding_character(&mut self, terminal_character: TerminalCharacter) {
+        self.preceding_char = Some(terminal_character);
     }
 }
 
-impl vte::Perform for Grid {
+impl Perform for Grid {
     fn print(&mut self, c: char) {
         let c = self.cursor.charsets[self.active_charset].map(c);
         // apparently, building TerminalCharacter like this without a "new" method
@@ -934,6 +967,7 @@ impl vte::Perform for Grid {
             character: c,
             styles: self.cursor.pending_styles,
         };
+        self.set_preceding_character(terminal_character);
         self.add_character(terminal_character);
     }
 
@@ -947,9 +981,10 @@ impl vte::Perform for Grid {
                 // tab
                 self.advance_to_next_tabstop(self.cursor.pending_styles);
             }
-            10 | 11 => {
+            10 | 11 | 12 => {
                 // 0a, newline
                 // 0b, vertical tabulation
+                // 0c, form feed
                 self.add_newline();
             }
             13 => {
@@ -966,7 +1001,7 @@ impl vte::Perform for Grid {
         }
     }
 
-    fn hook(&mut self, _params: &[i64], _intermediates: &[u8], _ignore: bool, _c: char) {
+    fn hook(&mut self, _params: &Params, _intermediates: &[u8], _ignore: bool, _c: char) {
         // TBD
     }
 
@@ -982,90 +1017,80 @@ impl vte::Perform for Grid {
         // TBD
     }
 
-    fn csi_dispatch(&mut self, params: &[i64], _intermediates: &[u8], _ignore: bool, c: char) {
+    fn csi_dispatch(&mut self, params: &Params, intermediates: &[u8], _ignore: bool, c: char) {
+        let mut params_iter = params.iter();
+        let mut next_param_or = |default: u16| {
+            params_iter
+                .next()
+                .map(|param| param[0])
+                .filter(|&param| param != 0)
+                .unwrap_or(default) as usize
+        };
         if c == 'm' {
             self.cursor
                 .pending_styles
-                .add_style_from_ansi_params(params);
-        } else if c == 'C' {
+                .add_style_from_ansi_params(&mut params_iter);
+        } else if c == 'C' || c == 'a' {
             // move cursor forward
-            let move_by = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let move_by = next_param_or(1);
             self.move_cursor_forward_until_edge(move_by);
         } else if c == 'K' {
             // clear line (0 => right, 1 => left, 2 => all)
-            if params[0] == 0 {
-                let mut char_to_replace = EMPTY_TERMINAL_CHARACTER;
-                char_to_replace.styles = self.cursor.pending_styles;
-                self.replace_characters_in_line_after_cursor(char_to_replace);
-            } else if params[0] == 1 {
-                let mut char_to_replace = EMPTY_TERMINAL_CHARACTER;
-                char_to_replace.styles = self.cursor.pending_styles;
-                self.replace_characters_in_line_before_cursor(char_to_replace);
-            } else if params[0] == 2 {
-                self.clear_cursor_line();
-            }
+            if let Some(clear_type) = params_iter.next().map(|param| param[0]) {
+                if clear_type == 0 {
+                    let mut char_to_replace = EMPTY_TERMINAL_CHARACTER;
+                    char_to_replace.styles = self.cursor.pending_styles;
+                    self.replace_characters_in_line_after_cursor(char_to_replace);
+                } else if clear_type == 1 {
+                    let mut char_to_replace = EMPTY_TERMINAL_CHARACTER;
+                    char_to_replace.styles = self.cursor.pending_styles;
+                    self.replace_characters_in_line_before_cursor(char_to_replace);
+                } else if clear_type == 2 {
+                    self.clear_cursor_line();
+                }
+            };
         } else if c == 'J' {
             // clear all (0 => below, 1 => above, 2 => all, 3 => saved)
             let mut char_to_replace = EMPTY_TERMINAL_CHARACTER;
             char_to_replace.styles = self.cursor.pending_styles;
-            if params[0] == 0 {
-                self.clear_all_after_cursor(char_to_replace);
-            } else if params[0] == 1 {
-                self.clear_all_before_cursor(char_to_replace);
-            } else if params[0] == 2 {
-                self.clear_all(char_to_replace);
-            }
-        // TODO: implement 1
+
+            if let Some(clear_type) = params_iter.next().map(|param| param[0]) {
+                if clear_type == 0 {
+                    self.clear_all_after_cursor(char_to_replace);
+                } else if clear_type == 1 {
+                    self.clear_all_before_cursor(char_to_replace);
+                } else if clear_type == 2 {
+                    self.fill_viewport(char_to_replace);
+                }
+            };
         } else if c == 'H' || c == 'f' {
             // goto row/col
             // we subtract 1 from the row/column because these are 1 indexed
-            // (except when they are 0, in which case they should be 1
-            // don't look at me, I don't make the rules)
-            let (row, col) = if params.len() == 1 {
-                if params[0] == 0 {
-                    (0, params[0] as usize)
-                } else {
-                    ((params[0] as usize).saturating_sub(1), params[0] as usize)
-                }
-            } else if params[0] == 0 {
-                (0, (params[1] as usize).saturating_sub(1))
-            } else {
-                (
-                    (params[0] as usize).saturating_sub(1),
-                    (params[1] as usize).saturating_sub(1),
-                )
-            };
+            let row = next_param_or(1).saturating_sub(1);
+            let col = next_param_or(1).saturating_sub(1);
             let pad_character = EMPTY_TERMINAL_CHARACTER;
             self.move_cursor_to(col, row, pad_character);
         } else if c == 'A' {
             // move cursor up until edge of screen
-            let move_up_count = if params[0] == 0 { 1 } else { params[0] };
+            let move_up_count = next_param_or(1);
             self.move_cursor_up(move_up_count as usize);
-        } else if c == 'B' {
+        } else if c == 'B' || c == 'e' {
             // move cursor down until edge of screen
-            let move_down_count = if params[0] == 0 { 1 } else { params[0] };
+            let move_down_count = next_param_or(1);
             let pad_character = EMPTY_TERMINAL_CHARACTER;
             self.move_cursor_down(move_down_count as usize, pad_character);
         } else if c == 'D' {
-            let move_back_count = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let move_back_count = next_param_or(1);
             self.move_cursor_back(move_back_count);
         } else if c == 'l' {
-            let first_intermediate_is_questionmark = match _intermediates.get(0) {
+            let first_intermediate_is_questionmark = match intermediates.get(0) {
                 Some(b'?') => true,
                 None => false,
                 _ => false,
             };
             if first_intermediate_is_questionmark {
-                match params.get(0) {
-                    Some(&1049) => {
+                match params_iter.next().map(|param| param[0]) {
+                    Some(1049) => {
                         if let Some((
                             alternative_lines_above,
                             alternative_viewport,
@@ -1081,44 +1106,44 @@ impl vte::Perform for Grid {
                         self.change_size(self.height, self.width); // the alternative_viewport might have been of a different size...
                         self.mark_for_rerender();
                     }
-                    Some(&25) => {
+                    Some(25) => {
                         self.hide_cursor();
                         self.mark_for_rerender();
                     }
-                    Some(&1) => {
+                    Some(1) => {
                         self.cursor_key_mode = false;
                     }
-                    Some(&3) => {
+                    Some(3) => {
                         // DECCOLM - only side effects
                         self.scroll_region = None;
                         self.clear_all(EMPTY_TERMINAL_CHARACTER);
                         self.cursor.x = 0;
                         self.cursor.y = 0;
                     }
-                    Some(&6) => {
+                    Some(6) => {
                         self.erasure_mode = false;
                     }
-                    Some(&7) => {
+                    Some(7) => {
                         self.disable_linewrap = true;
                     }
                     _ => {}
                 };
-            } else if let Some(&4) = params.get(0) {
+            } else if let Some(4) = params_iter.next().map(|param| param[0]) {
                 self.insert_mode = false;
             }
         } else if c == 'h' {
-            let first_intermediate_is_questionmark = match _intermediates.get(0) {
+            let first_intermediate_is_questionmark = match intermediates.get(0) {
                 Some(b'?') => true,
                 None => false,
                 _ => false,
             };
             if first_intermediate_is_questionmark {
-                match params.get(0) {
-                    Some(&25) => {
+                match params_iter.next().map(|param| param[0]) {
+                    Some(25) => {
                         self.show_cursor();
                         self.mark_for_rerender();
                     }
-                    Some(&1049) => {
+                    Some(1049) => {
                         let current_lines_above = std::mem::replace(
                             &mut self.lines_above,
                             VecDeque::with_capacity(SCROLL_BACK),
@@ -1130,99 +1155,75 @@ impl vte::Perform for Grid {
                             Some((current_lines_above, current_viewport, current_cursor));
                         self.clear_viewport_before_rendering = true;
                     }
-                    Some(&1) => {
+                    Some(1) => {
                         self.cursor_key_mode = true;
                     }
-                    Some(&3) => {
+                    Some(3) => {
                         // DECCOLM - only side effects
                         self.scroll_region = None;
                         self.clear_all(EMPTY_TERMINAL_CHARACTER);
                         self.cursor.x = 0;
                         self.cursor.y = 0;
                     }
-                    Some(&6) => {
+                    Some(6) => {
                         self.erasure_mode = true;
                     }
-                    Some(&7) => {
+                    Some(7) => {
                         self.disable_linewrap = false;
                     }
                     _ => {}
                 };
-            } else if let Some(&4) = params.get(0) {
+            } else if let Some(4) = params_iter.next().map(|param| param[0]) {
                 self.insert_mode = true;
             }
         } else if c == 'r' {
             if params.len() > 1 {
-                // minus 1 because these are 1 indexed
-                let top_line_index = (params[0] as usize).saturating_sub(1);
-                let bottom_line_index = (params[1] as usize).saturating_sub(1);
-                self.set_scroll_region(top_line_index, bottom_line_index);
+                let top = (next_param_or(1) as usize).saturating_sub(1);
+                let bottom = params_iter
+                    .next()
+                    .map(|param| param[0] as usize)
+                    .filter(|&param| param != 0)
+                    .map(|bottom| bottom.saturating_sub(1));
+                self.set_scroll_region(top, bottom);
                 if self.erasure_mode {
-                    self.move_cursor_to_line(top_line_index, EMPTY_TERMINAL_CHARACTER);
+                    self.move_cursor_to_line(top, EMPTY_TERMINAL_CHARACTER);
                     self.move_cursor_to_beginning_of_line();
                 }
-                self.show_cursor();
             } else {
                 self.clear_scroll_region();
             }
         } else if c == 'M' {
             // delete lines if currently inside scroll region
-            let line_count_to_delete = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let line_count_to_delete = next_param_or(1);
             let pad_character = EMPTY_TERMINAL_CHARACTER;
             self.delete_lines_in_scroll_region(line_count_to_delete, pad_character);
         } else if c == 'L' {
             // insert blank lines if inside scroll region
-            let line_count_to_add = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let line_count_to_add = next_param_or(1);
             let pad_character = EMPTY_TERMINAL_CHARACTER;
             self.add_empty_lines_in_scroll_region(line_count_to_add, pad_character);
-        } else if c == 'q' {
-            // ignore for now to run on mac
-        } else if c == 'G' {
-            let column = if params[0] == 0 {
-                0
-            } else {
-                params[0] as usize - 1
-            };
+        } else if c == 'G' || c == '`' {
+            let column = next_param_or(1).saturating_sub(1);
             self.move_cursor_to_column(column);
         } else if c == 'g' {
-            if params[0] == 0 {
+            let clear_type = next_param_or(0);
+            if clear_type == 0 {
                 self.clear_tabstop(self.cursor.x);
-            } else if params[0] == 3 {
+            } else if clear_type == 3 {
                 self.clear_all_tabstops();
             }
         } else if c == 'd' {
             // goto line
-            let line = if params[0] == 0 {
-                1
-            } else {
-                // minus 1 because this is 1 indexed
-                params[0] as usize - 1
-            };
+            let line = next_param_or(1).saturating_sub(1);
             let pad_character = EMPTY_TERMINAL_CHARACTER;
             self.move_cursor_to_line(line, pad_character);
         } else if c == 'P' {
             // erase characters
-            let count = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let count = next_param_or(1);
             self.erase_characters(count, self.cursor.pending_styles);
         } else if c == 'X' {
             // erase characters and replace with empty characters of current style
-            let count = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let count = next_param_or(1);
             self.replace_with_empty_chars(count, self.cursor.pending_styles);
         } else if c == 'T' {
             /*
@@ -1230,36 +1231,120 @@ impl vte::Perform for Grid {
              * Scroll down, new lines inserted at top of screen
              * [4T = Scroll down 4, bring previous lines back into view
              */
-            let line_count: i64 = *params.get(0).expect("A number of lines was expected.");
-
-            if line_count >= 0 {
-                self.rotate_scroll_region_up(line_count as usize);
-            } else {
-                // TODO: can this actually happen?
-                self.rotate_scroll_region_down(line_count.abs() as usize);
-            }
+            let line_count = next_param_or(1);
+            self.rotate_scroll_region_up(line_count as usize);
         } else if c == 'S' {
             // move scroll up
-            let count = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let count = next_param_or(1);
             self.rotate_scroll_region_down(count);
         } else if c == 's' {
             self.save_cursor_position();
         } else if c == 'u' {
             self.restore_cursor_position();
         } else if c == '@' {
-            let count = if params[0] == 0 {
-                1
-            } else {
-                params[0] as usize
-            };
+            let count = next_param_or(1);
             for _ in 0..count {
                 // TODO: should this be styled?
                 self.insert_character_at_cursor_position(EMPTY_TERMINAL_CHARACTER);
             }
+        } else if c == 'b' {
+            if let Some(c) = self.preceding_char {
+                for _ in 0..next_param_or(1) {
+                    self.add_character(c);
+                }
+            }
+        } else if c == 'E' {
+            let count = next_param_or(1);
+            let pad_character = EMPTY_TERMINAL_CHARACTER;
+            self.move_cursor_down(count, pad_character);
+        } else if c == 'F' {
+            let count = next_param_or(1);
+            self.move_cursor_up(count);
+            self.move_cursor_to_beginning_of_line();
+        } else if c == 'I' {
+            for _ in 0..next_param_or(1) {
+                self.advance_to_next_tabstop(self.cursor.pending_styles);
+            }
+        } else if c == 'q' {
+            let first_intermediate_is_space = matches!(intermediates.get(0), Some(b' '));
+            if first_intermediate_is_space {
+                // DECSCUSR (CSI Ps SP q) -- Set Cursor Style.
+                let cursor_style_id = next_param_or(0);
+                let shape = match cursor_style_id {
+                    0 | 2 => Some(CursorShape::Block),
+                    1 => Some(CursorShape::BlinkingBlock),
+                    3 => Some(CursorShape::BlinkingUnderline),
+                    4 => Some(CursorShape::Underline),
+                    5 => Some(CursorShape::BlinkingBeam),
+                    6 => Some(CursorShape::Beam),
+                    _ => None,
+                };
+                if let Some(cursor_shape) = shape {
+                    self.cursor.change_shape(cursor_shape);
+                }
+            }
+        } else if c == 'Z' {
+            for _ in 0..next_param_or(1) {
+                self.move_to_previous_tabstop();
+            }
+        } else if c == 'c' {
+            // identify terminal
+            // https://vt100.net/docs/vt510-rm/DA1.html
+            match intermediates.get(0) {
+                None | Some(0) => {
+                    // primary device attributes
+                    let terminal_capabilities = "\u{1b}[?6c";
+                    self.pending_messages_to_pty
+                        .push(terminal_capabilities.as_bytes().to_vec());
+                }
+                Some(b'>') => {
+                    // secondary device attributes
+                    let version = version_number(VERSION);
+                    let text = format!("\u{1b}[>0;{};1c", version);
+                    self.pending_messages_to_pty.push(text.as_bytes().to_vec());
+                }
+                _ => {}
+            }
+        } else if c == 'n' {
+            // DSR - device status report
+            // https://vt100.net/docs/vt510-rm/DSR.html
+            match next_param_or(0) {
+                5 => {
+                    // report terminal status
+                    let all_good = "\u{1b}[0n";
+                    self.pending_messages_to_pty
+                        .push(all_good.as_bytes().to_vec());
+                }
+                6 => {
+                    // CPR - cursor position report
+                    let position_report =
+                        format!("\x1b[{};{}R", self.cursor.y + 1, self.cursor.x + 1);
+                    self.pending_messages_to_pty
+                        .push(position_report.as_bytes().to_vec());
+                }
+                _ => {}
+            }
+        } else if c == 't' {
+            match next_param_or(1) as usize {
+                14 => {
+                    // TODO: report text area size in pixels, currently unimplemented
+                    // to solve this we probably need to query the user's terminal for the cursor
+                    // size and then use it as a multiplier
+                }
+                18 => {
+                    // report text area
+                    let text_area_report = format!("\x1b[8;{};{}t", self.height, self.width);
+                    self.pending_messages_to_pty
+                        .push(text_area_report.as_bytes().to_vec());
+                }
+                22 => {
+                    // TODO: push title
+                }
+                23 => {
+                    // TODO: pop title
+                }
+                _ => {}
+            }
         } else {
             let result = debug_log_to_file(format!("Unhandled csi: {}->{:?}", c, params));
             #[cfg(not(test))]
@@ -1306,6 +1391,7 @@ impl vte::Perform for Grid {
                 self.move_cursor_to_beginning_of_line();
             }
             (b'M', None) => {
+                // TODO: if cursor is at the top, it should go down one
                 self.move_cursor_up_with_scrolling(1);
             }
             (b'c', None) => {
@@ -1317,6 +1403,11 @@ impl vte::Perform for Grid {
             (b'7', None) => {
                 self.save_cursor_position();
             }
+            (b'Z', None) => {
+                let terminal_capabilities = "\u{1b}[?6c";
+                self.pending_messages_to_pty
+                    .push(terminal_capabilities.as_bytes().to_vec());
+            }
             (b'8', None) => {
                 self.restore_cursor_position();
             }
