@@ -1,15 +1,16 @@
-use crate::tab::Pane;
-use ::nix::pty::Winsize;
-use ::std::os::unix::io::RawFd;
-use serde::{Deserialize, Serialize};
 use std::fmt::Debug;
+use std::os::unix::io::RawFd;
 use std::time::Instant;
 
+use nix::pty::Winsize;
+use serde::{Deserialize, Serialize};
+
 use crate::panes::grid::Grid;
 use crate::panes::terminal_character::{
-    CharacterStyles, TerminalCharacter, EMPTY_TERMINAL_CHARACTER,
+    CharacterStyles, CursorShape, TerminalCharacter, EMPTY_TERMINAL_CHARACTER,
 };
-use crate::pty_bus::VteBytes;
+use crate::pty::VteBytes;
+use crate::tab::Pane;
 
 #[derive(PartialEq, Eq, Ord, PartialOrd, Hash, Clone, Copy, Debug, Serialize, Deserialize)]
 pub enum PaneId {
@@ -290,6 +291,19 @@ impl Pane for TerminalPane {
     fn set_active_at(&mut self, time: Instant) {
         self.active_at = time;
     }
+    fn cursor_shape_csi(&self) -> String {
+        match self.grid.cursor_shape() {
+            CursorShape::Block => "\u{1b}[0 q".to_string(),
+            CursorShape::BlinkingBlock => "\u{1b}[1 q".to_string(),
+            CursorShape::Underline => "\u{1b}[4 q".to_string(),
+            CursorShape::BlinkingUnderline => "\u{1b}[3 q".to_string(),
+            CursorShape::Beam => "\u{1b}[6 q".to_string(),
+            CursorShape::BlinkingBeam => "\u{1b}[5 q".to_string(),
+        }
+    }
+    fn drain_messages_to_pty(&mut self) -> Vec<Vec<u8>> {
+        self.grid.pending_messages_to_pty.drain(..).collect()
+    }
 }
 
 impl TerminalPane {
