@@ -2,11 +2,12 @@
 //! as well as how they should be resized
 
 use crate::client::pane_resizer::PaneResizer;
-use crate::common::{input::handler::parse_keys, SenderWithContext};
+use crate::common::input::handler::parse_keys;
+use crate::common::thread_bus::ThreadSenders;
 use crate::layout::Layout;
 use crate::os_input_output::ServerOsApi;
 use crate::panes::{PaneId, PositionAndSize, TerminalPane};
-use crate::pty_bus::{PtyInstruction, VteBytes};
+use crate::pty::{PtyInstruction, VteBytes};
 use crate::server::ServerInstruction;
 use crate::utils::shared::adjust_to_size;
 use crate::wasm_vm::PluginInstruction;
@@ -69,9 +70,7 @@ pub struct Tab {
     full_screen_ws: PositionAndSize,
     fullscreen_is_active: bool,
     os_api: Box<dyn ServerOsApi>,
-    send_plugin_instructions: SenderWithContext<PluginInstruction>,
-    send_pty_instructions: SenderWithContext<PtyInstruction>,
-    send_server_instructions: SenderWithContext<ServerInstruction>,
+    pub senders: ThreadSenders,
     synchronize_is_active: bool,
     should_clear_display_before_rendering: bool,
     pub mode_info: ModeInfo,
@@ -133,6 +132,9 @@ pub trait Pane {
     fn clear_scroll(&mut self);
     fn active_at(&self) -> Instant;
     fn set_active_at(&mut self, instant: Instant);
+    fn cursor_shape_csi(&self) -> String {
+        "\u{1b}[0 q".to_string() // default to non blinking block
+    }
 
     fn right_boundary_x_coords(&self) -> usize {
         self.x() + self.columns()
@@ -216,10 +218,15 @@ pub trait Pane {
     fn invisible_borders(&self) -> bool {
         false
     }
+    fn drain_messages_to_pty(&mut self) -> Vec<Vec<u8>> {
+        // TODO: this is only relevant to terminal panes
+        // we should probably refactor away from this trait at some point
+        vec![]
+    }
 }
 
 impl Tab {
-    // FIXME: Too many arguments here! Maybe bundle all of the senders for the whole program in a struct?
+    // FIXME: Still too many arguments for clippy to be happy...
     #[allow(clippy::too_many_arguments)]
     pub fn new(
         index: usize,
@@ -227,9 +234,7 @@ impl Tab {
         name: String,
         full_screen_ws: &PositionAndSize,
         mut os_api: Box<dyn ServerOsApi>,
-        send_plugin_instructions: SenderWithContext<PluginInstruction>,
-        send_pty_instructions: SenderWithContext<PtyInstruction>,
-        send_server_instructions: SenderWithContext<ServerInstruction>,
+        senders: ThreadSenders,
         max_panes: Option<usize>,
         pane_id: Option<PaneId>,
         mode_info: ModeInfo,
@@ -261,9 +266,7 @@ impl Tab {
             fullscreen_is_active: false,
             synchronize_is_active: false,
             os_api,
-            send_plugin_instructions,
-            send_pty_instructions,
-            send_server_instructions,
+            senders,
             should_clear_display_before_rendering: false,
             mode_info,
             input_mode,
@@ -315,14 +318,14 @@ impl Tab {
             // Just a regular terminal
             if let Some(plugin) = &layout.plugin {
                 let (pid_tx, pid_rx) = channel();
-                self.send_plugin_instructions
-                    .send(PluginInstruction::Load(pid_tx, plugin.clone()))
+                self.senders
+                    .send_to_plugin(PluginInstruction::Load(pid_tx, plugin.clone()))
                     .unwrap();
                 let pid = pid_rx.recv().unwrap();
                 let mut new_plugin = PluginPane::new(
                     pid,
                     *position_and_size,
-                    self.send_plugin_instructions.clone(),
+                    self.senders.to_plugin.as_ref().unwrap().clone(),
                 );
                 if let Some(max_rows) = position_and_size.max_rows {
                     new_plugin.set_max_height(max_rows);
@@ -332,8 +335,8 @@ impl Tab {
                 }
                 self.panes.insert(PaneId::Plugin(pid), Box::new(new_plugin));
                 // Send an initial mode update to the newly loaded plugin only!
-                self.send_plugin_instructions
-                    .send(PluginInstruction::Update(
+                self.senders
+                    .send_to_plugin(PluginInstruction::Update(
                         Some(pid),
                         Event::ModeUpdate(self.mode_info.clone()),
                     ))
@@ -355,8 +358,8 @@ impl Tab {
             // this is a bit of a hack and happens because we don't have any central location that
             // can query the screen as to how many panes it needs to create a layout
             // fixing this will require a bit of an architecture change
-            self.send_pty_instructions
-                .send(PtyInstruction::ClosePane(PaneId::Terminal(*unused_pid)))
+            self.senders
+                .send_to_pty(PtyInstruction::ClosePane(PaneId::Terminal(*unused_pid)))
                 .unwrap();
         }
         self.active_terminal = self.panes.iter().map(|(id, _)| id.to_owned()).next();
@@ -400,9 +403,9 @@ impl Tab {
                 },
             );
             if terminal_id_to_split.is_none() {
-                self.send_pty_instructions
-                    .send(PtyInstruction::ClosePane(pid))
-                    .unwrap(); // we can't open this pane, close the pty
+                self.senders
+                    .send_to_pty(PtyInstruction::ClosePane(pid)) // we can't open this pane, close the pty
+                    .unwrap();
                 return; // likely no terminal large enough to split
             }
             let terminal_id_to_split = terminal_id_to_split.unwrap();
@@ -481,9 +484,9 @@ impl Tab {
             let active_pane_id = &self.get_active_pane_id().unwrap();
             let active_pane = self.panes.get_mut(active_pane_id).unwrap();
             if active_pane.rows() < MIN_TERMINAL_HEIGHT * 2 + 1 {
-                self.send_pty_instructions
-                    .send(PtyInstruction::ClosePane(pid))
-                    .unwrap(); // we can't open this pane, close the pty
+                self.senders
+                    .send_to_pty(PtyInstruction::ClosePane(pid)) // we can't open this pane, close the pty
+                    .unwrap();
                 return;
             }
             let terminal_ws = PositionAndSize {
@@ -538,9 +541,9 @@ impl Tab {
             let active_pane_id = &self.get_active_pane_id().unwrap();
             let active_pane = self.panes.get_mut(active_pane_id).unwrap();
             if active_pane.columns() < MIN_TERMINAL_WIDTH * 2 + 1 {
-                self.send_pty_instructions
-                    .send(PtyInstruction::ClosePane(pid))
-                    .unwrap(); // we can't open this pane, close the pty
+                self.senders
+                    .send_to_pty(PtyInstruction::ClosePane(pid)) // we can't open this pane, close the pty
+                    .unwrap();
                 return;
             }
             let terminal_ws = PositionAndSize {
@@ -597,33 +600,31 @@ impl Tab {
     }
     pub fn handle_pty_bytes(&mut self, pid: RawFd, bytes: VteBytes) {
         // if we don't have the terminal in self.terminals it's probably because
-        // of a race condition where the terminal was created in pty_bus but has not
+        // of a race condition where the terminal was created in pty but has not
         // yet been created in Screen. These events are currently not buffered, so
         // if you're debugging seemingly randomly missing stdout data, this is
         // the reason
         if let Some(terminal_output) = self.panes.get_mut(&PaneId::Terminal(pid)) {
             terminal_output.handle_pty_bytes(bytes);
+            let messages_to_pty = terminal_output.drain_messages_to_pty();
+            for message in messages_to_pty {
+                self.write_to_pane_id(message, PaneId::Terminal(pid));
+            }
         }
     }
     pub fn write_to_terminals_on_current_tab(&mut self, input_bytes: Vec<u8>) {
         let pane_ids = self.get_pane_ids();
-        pane_ids.iter().for_each(|pane_id| match pane_id {
-            PaneId::Terminal(pid) => {
-                self.write_to_pane_id(input_bytes.clone(), *pid);
-            }
-            PaneId::Plugin(_) => {}
+        pane_ids.iter().for_each(|&pane_id| {
+            self.write_to_pane_id(input_bytes.clone(), pane_id);
         });
     }
-    pub fn write_to_pane_id(&mut self, mut input_bytes: Vec<u8>, pid: RawFd) {
-        self.os_api
-            .write_to_tty_stdin(pid, &mut input_bytes)
-            .expect("failed to write to terminal");
-        self.os_api.tcdrain(pid).expect("failed to drain terminal");
-    }
     pub fn write_to_active_terminal(&mut self, input_bytes: Vec<u8>) {
-        match self.get_active_pane_id() {
-            Some(PaneId::Terminal(active_terminal_id)) => {
-                let active_terminal = self.get_active_pane().unwrap();
+        self.write_to_pane_id(input_bytes, self.get_active_pane_id().unwrap());
+    }
+    pub fn write_to_pane_id(&mut self, input_bytes: Vec<u8>, pane_id: PaneId) {
+        match pane_id {
+            PaneId::Terminal(active_terminal_id) => {
+                let active_terminal = self.panes.get(&pane_id).unwrap();
                 let mut adjusted_input = active_terminal.adjust_input_to_terminal(input_bytes);
                 self.os_api
                     .write_to_tty_stdin(active_terminal_id, &mut adjusted_input)
@@ -632,14 +633,13 @@ impl Tab {
                     .tcdrain(active_terminal_id)
                     .expect("failed to drain terminal");
             }
-            Some(PaneId::Plugin(pid)) => {
+            PaneId::Plugin(pid) => {
                 for key in parse_keys(&input_bytes) {
-                    self.send_plugin_instructions
-                        .send(PluginInstruction::Update(Some(pid), Event::KeyPress(key)))
+                    self.senders
+                        .send_to_plugin(PluginInstruction::Update(Some(pid), Event::KeyPress(key)))
                         .unwrap()
                 }
             }
-            _ => {}
         }
     }
     pub fn get_active_terminal_cursor_position(&self) -> Option<(usize, usize)> {
@@ -774,10 +774,12 @@ impl Tab {
         match self.get_active_terminal_cursor_position() {
             Some((cursor_position_x, cursor_position_y)) => {
                 let show_cursor = "\u{1b}[?25h";
+                let change_cursor_shape = self.get_active_pane().unwrap().cursor_shape_csi();
                 let goto_cursor_position = &format!(
-                    "\u{1b}[{};{}H\u{1b}[m",
+                    "\u{1b}[{};{}H\u{1b}[m{}",
                     cursor_position_y + 1,
-                    cursor_position_x + 1
+                    cursor_position_x + 1,
+                    change_cursor_shape
                 ); // goto row/col
                 output.push_str(show_cursor);
                 output.push_str(goto_cursor_position);
@@ -788,8 +790,8 @@ impl Tab {
             }
         }
 
-        self.send_server_instructions
-            .send(ServerInstruction::Render(Some(output)))
+        self.senders
+            .send_to_server(ServerInstruction::Render(Some(output)))
             .unwrap();
     }
     fn get_panes(&self) -> impl Iterator<Item = (&PaneId, &Box<dyn Pane>)> {
@@ -1860,12 +1862,13 @@ impl Tab {
         }
         self.render();
     }
-    pub fn move_focus_left(&mut self) {
+    // returns a boolean that indicates whether the focus moved
+    pub fn move_focus_left(&mut self) -> bool {
         if !self.has_selectable_panes() {
-            return;
+            return false;
         }
         if self.fullscreen_is_active {
-            return;
+            return false;
         }
         let active_terminal = self.get_active_pane();
         if let Some(active) = active_terminal {
@@ -1880,6 +1883,8 @@ impl Tab {
             match next_index {
                 Some(&p) => {
                     self.active_terminal = Some(p);
+                    self.render();
+                    return true;
                 }
                 None => {
                     self.active_terminal = Some(active.pid());
@@ -1888,7 +1893,7 @@ impl Tab {
         } else {
             self.active_terminal = Some(active_terminal.unwrap().pid());
         }
-        self.render();
+        false
     }
     pub fn move_focus_down(&mut self) {
         if !self.has_selectable_panes() {
@@ -1950,12 +1955,13 @@ impl Tab {
         }
         self.render();
     }
-    pub fn move_focus_right(&mut self) {
+    // returns a boolean that indicates whether the focus moved
+    pub fn move_focus_right(&mut self) -> bool {
         if !self.has_selectable_panes() {
-            return;
+            return false;
         }
         if self.fullscreen_is_active {
-            return;
+            return false;
         }
         let active_terminal = self.get_active_pane();
         if let Some(active) = active_terminal {
@@ -1970,6 +1976,8 @@ impl Tab {
             match next_index {
                 Some(&p) => {
                     self.active_terminal = Some(p);
+                    self.render();
+                    return true;
                 }
                 None => {
                     self.active_terminal = Some(active.pid());
@@ -1978,7 +1986,7 @@ impl Tab {
         } else {
             self.active_terminal = Some(active_terminal.unwrap().pid());
         }
-        self.render();
+        false
     }
     fn horizontal_borders(&self, terminals: &[PaneId]) -> HashSet<usize> {
         terminals.iter().fold(HashSet::new(), |mut borders, t| {
@@ -2093,8 +2101,8 @@ impl Tab {
         if let Some(max_panes) = self.max_panes {
             let terminals = self.get_pane_ids();
             for &pid in terminals.iter().skip(max_panes - 1) {
-                self.send_pty_instructions
-                    .send(PtyInstruction::ClosePane(pid))
+                self.senders
+                    .send_to_pty(PtyInstruction::ClosePane(pid))
                     .unwrap();
                 self.close_pane_without_rerender(pid);
             }
@@ -2205,8 +2213,8 @@ impl Tab {
     pub fn close_focused_pane(&mut self) {
         if let Some(active_pane_id) = self.get_active_pane_id() {
             self.close_pane(active_pane_id);
-            self.send_pty_instructions
-                .send(PtyInstruction::ClosePane(active_pane_id))
+            self.senders
+                .send_to_pty(PtyInstruction::ClosePane(active_pane_id))
                 .unwrap();
         }
     }
