@@ -4,14 +4,14 @@ use super::actions::Action;
 use super::keybinds::Keybinds;
 use crate::client::ClientInstruction;
 use crate::common::input::config::Config;
-use crate::common::{SenderWithContext, OPENCALLS};
+use crate::common::thread_bus::{SenderWithContext, OPENCALLS};
 use crate::errors::ContextType;
 use crate::os_input_output::ClientOsApi;
 use crate::server::ServerInstruction;
 use crate::CommandIsExecuting;
 
 use termion::input::{TermRead, TermReadEventsAndRaw};
-use zellij_tile::data::{InputMode, Key, ModeInfo, Palette};
+use zellij_tile::data::{InputMode, Key, ModeInfo, Palette, PluginCapabilities};
 
 /// Handles the dispatching of [`Action`]s according to the current
 /// [`InputMode`], and keep tracks of the current [`InputMode`].
@@ -23,6 +23,7 @@ struct InputHandler {
     command_is_executing: CommandIsExecuting,
     send_client_instructions: SenderWithContext<ClientInstruction>,
     should_exit: bool,
+    pasting: bool,
 }
 
 impl InputHandler {
@@ -40,6 +41,7 @@ impl InputHandler {
             command_is_executing,
             send_client_instructions,
             should_exit: false,
+            pasting: false,
         }
     }
 
@@ -49,6 +51,8 @@ impl InputHandler {
         let mut err_ctx = OPENCALLS.with(|ctx| *ctx.borrow());
         err_ctx.add_call(ContextType::StdinHandler);
         let alt_left_bracket = vec![27, 91];
+        let bracketed_paste_start = vec![27, 91, 50, 48, 48, 126]; // \u{1b}[200~
+        let bracketed_paste_end = vec![27, 91, 50, 48, 49, 126]; // \u{1b}[201
         loop {
             if self.should_exit {
                 break;
@@ -67,6 +71,14 @@ impl InputHandler {
                             if unsupported_key == alt_left_bracket {
                                 let key = Key::Alt('[');
                                 self.handle_key(&key, raw_bytes);
+                            } else if unsupported_key == bracketed_paste_start {
+                                self.pasting = true;
+                            } else if unsupported_key == bracketed_paste_end {
+                                self.pasting = false;
+                            } else {
+                                // this is a hack because termion doesn't recognize certain keys
+                                // in this case we just forward it to the terminal
+                                self.handle_unknown_key(raw_bytes);
                             }
                         }
                         termion::event::Event::Mouse(_) => {
@@ -79,12 +91,28 @@ impl InputHandler {
             }
         }
     }
+    fn handle_unknown_key(&mut self, raw_bytes: Vec<u8>) {
+        if self.mode == InputMode::Normal || self.mode == InputMode::Locked {
+            let action = Action::Write(raw_bytes);
+            self.dispatch_action(action);
+        }
+    }
     fn handle_key(&mut self, key: &Key, raw_bytes: Vec<u8>) {
         let keybinds = &self.config.keybinds;
-        for action in Keybinds::key_to_actions(&key, raw_bytes, &self.mode, keybinds) {
-            let should_exit = self.dispatch_action(action);
-            if should_exit {
-                self.should_exit = true;
+        if self.pasting {
+            // we're inside a paste block, if we're in a mode that allows sending text to the
+            // terminal, send all text directly without interpreting it
+            // otherwise, just discard the input
+            if self.mode == InputMode::Normal || self.mode == InputMode::Locked {
+                let action = Action::Write(raw_bytes);
+                self.dispatch_action(action);
+            }
+        } else {
+            for action in Keybinds::key_to_actions(&key, raw_bytes, &self.mode, keybinds) {
+                let should_exit = self.dispatch_action(action);
+                if should_exit {
+                    self.should_exit = true;
+                }
             }
         }
     }
@@ -119,7 +147,8 @@ impl InputHandler {
             | Action::GoToNextTab
             | Action::GoToPreviousTab
             | Action::CloseTab
-            | Action::GoToTab(_) => {
+            | Action::GoToTab(_)
+            | Action::MoveFocusOrTab(_) => {
                 self.command_is_executing.blocking_input_thread();
                 self.os_input
                     .send_to_server(ServerInstruction::Action(action));
@@ -146,7 +175,11 @@ impl InputHandler {
 /// Creates a [`Help`] struct indicating the current [`InputMode`] and its keybinds
 /// (as pairs of [`String`]s).
 // TODO this should probably be automatically generated in some way
-pub fn get_mode_info(mode: InputMode, palette: Palette) -> ModeInfo {
+pub fn get_mode_info(
+    mode: InputMode,
+    palette: Palette,
+    capabilities: PluginCapabilities,
+) -> ModeInfo {
     let mut keybinds: Vec<(String, String)> = vec![];
     match mode {
         InputMode::Normal | InputMode::Locked => {}
@@ -160,7 +193,6 @@ pub fn get_mode_info(mode: InputMode, palette: Palette) -> ModeInfo {
             keybinds.push(("d".to_string(), "Down split".to_string()));
             keybinds.push(("r".to_string(), "Right split".to_string()));
             keybinds.push(("x".to_string(), "Close".to_string()));
-            keybinds.push(("s".to_string(), "Sync".to_string()));
             keybinds.push(("f".to_string(), "Fullscreen".to_string()));
         }
         InputMode::Tab => {
@@ -168,6 +200,7 @@ pub fn get_mode_info(mode: InputMode, palette: Palette) -> ModeInfo {
             keybinds.push(("n".to_string(), "New".to_string()));
             keybinds.push(("x".to_string(), "Close".to_string()));
             keybinds.push(("r".to_string(), "Rename".to_string()));
+            keybinds.push(("s".to_string(), "Sync".to_string()));
         }
         InputMode::Scroll => {
             keybinds.push(("↓↑".to_string(), "Scroll".to_string()));
@@ -181,6 +214,7 @@ pub fn get_mode_info(mode: InputMode, palette: Palette) -> ModeInfo {
         mode,
         keybinds,
         palette,
+        capabilities,
     }
 }
 
