@@ -6,15 +6,13 @@ mod server;
 mod tests;
 
 use client::{boundaries, layout, panes, start_client, tab};
-use common::{
-    command_is_executing, errors, os_input_output, pty_bus, screen, setup, utils, wasm_vm,
-};
+use common::{command_is_executing, errors, os_input_output, pty, screen, setup, utils, wasm_vm};
 use server::start_server;
 use structopt::StructOpt;
 
 use crate::cli::CliArgs;
 use crate::command_is_executing::CommandIsExecuting;
-use crate::common::input::config::Config;
+use crate::common::input::{config::Config, options::Options};
 use crate::os_input_output::{get_client_os_input, get_server_os_input, ClientOsApi, ServerOsApi};
 use crate::utils::{
     consts::{ZELLIJ_TMP_DIR, ZELLIJ_TMP_LOG_DIR},
@@ -31,6 +29,8 @@ pub fn main() {
             std::process::exit(1);
         }
     };
+    let config_options = Options::from_cli(&config.options, opts.option.clone());
+
     if let Some(crate::cli::ConfigCli::GenerateCompletion { shell }) = opts.option {
         let shell = match shell.as_ref() {
             "bash" => structopt::clap::Shell::Bash,
@@ -47,13 +47,19 @@ pub fn main() {
         CliArgs::clap().gen_completions_to("zellij", shell, &mut out);
     } else if let Some(crate::cli::ConfigCli::Setup { .. }) = opts.option {
         setup::dump_default_config().expect("Failed to print to stdout");
-        std::process::exit(1);
+        std::process::exit(0);
     } else {
         atomic_create_dir(&*ZELLIJ_TMP_DIR).unwrap();
         atomic_create_dir(&*ZELLIJ_TMP_LOG_DIR).unwrap();
         let server_os_input = get_server_os_input();
         let os_input = get_client_os_input();
-        start(Box::new(os_input), opts, Box::new(server_os_input), config);
+        start(
+            Box::new(os_input),
+            opts,
+            Box::new(server_os_input),
+            config,
+            config_options,
+        );
     }
 }
 pub fn start(
@@ -61,8 +67,9 @@ pub fn start(
     opts: CliArgs,
     server_os_input: Box<dyn ServerOsApi>,
     config: Config,
+    config_options: Options,
 ) {
-    let ipc_thread = start_server(server_os_input);
+    let ipc_thread = start_server(server_os_input, config_options);
     start_client(client_os_input, opts, config);
     drop(ipc_thread.join());
 }
