@@ -1,13 +1,13 @@
 use crate::panes::PositionAndSize;
 use ::insta::assert_snapshot;
 
-use crate::common::input::config::Config;
+use crate::common::input::{config::Config, options::Options};
 use crate::tests::fakes::FakeInputOutput;
 use crate::tests::utils::commands::{
-    PANE_MODE, QUIT, SCROLL_DOWN_IN_SCROLL_MODE, SCROLL_MODE, SCROLL_PAGE_DOWN_IN_SCROLL_MODE,
-    SCROLL_PAGE_UP_IN_SCROLL_MODE, SCROLL_UP_IN_SCROLL_MODE, SPAWN_TERMINAL_IN_PANE_MODE,
-    SPLIT_DOWN_IN_PANE_MODE, SPLIT_RIGHT_IN_PANE_MODE,
-    TOGGLE_ACTIVE_TERMINAL_FULLSCREEN_IN_PANE_MODE,
+    BRACKETED_PASTE_END, BRACKETED_PASTE_START, PANE_MODE, QUIT, SCROLL_DOWN_IN_SCROLL_MODE,
+    SCROLL_MODE, SCROLL_PAGE_DOWN_IN_SCROLL_MODE, SCROLL_PAGE_UP_IN_SCROLL_MODE,
+    SCROLL_UP_IN_SCROLL_MODE, SPAWN_TERMINAL_IN_PANE_MODE, SPLIT_DOWN_IN_PANE_MODE,
+    SPLIT_RIGHT_IN_PANE_MODE, TOGGLE_ACTIVE_TERMINAL_FULLSCREEN_IN_PANE_MODE,
 };
 use crate::tests::utils::{get_next_to_last_snapshot, get_output_frame_snapshots};
 use crate::{start, CliArgs};
@@ -32,6 +32,7 @@ pub fn starts_with_one_terminal() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -60,6 +61,7 @@ pub fn split_terminals_vertically() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -88,6 +90,7 @@ pub fn split_terminals_horizontally() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -123,6 +126,7 @@ pub fn split_largest_terminal() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -151,6 +155,7 @@ pub fn cannot_split_terminals_vertically_when_active_terminal_is_too_small() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -179,6 +184,7 @@ pub fn cannot_split_terminals_horizontally_when_active_terminal_is_too_small() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -207,6 +213,7 @@ pub fn cannot_split_largest_terminal_when_there_is_no_room() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -243,6 +250,7 @@ pub fn scrolling_up_inside_a_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -281,6 +289,7 @@ pub fn scrolling_down_inside_a_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -316,6 +325,7 @@ pub fn scrolling_page_up_inside_a_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -354,6 +364,7 @@ pub fn scrolling_page_down_inside_a_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -393,6 +404,7 @@ pub fn max_panes() {
         opts,
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -430,6 +442,48 @@ pub fn toggle_focused_pane_fullscreen() {
         opts,
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
+    );
+    let output_frames = fake_input_output
+        .stdout_writer
+        .output_frames
+        .lock()
+        .unwrap();
+    let snapshots = get_output_frame_snapshots(&output_frames, &fake_win_size);
+    let snapshot_before_quit =
+        get_next_to_last_snapshot(snapshots).expect("could not find snapshot");
+    assert_snapshot!(snapshot_before_quit);
+}
+
+#[test]
+pub fn bracketed_paste() {
+    // bracketed paste (https://xfree86.org/current/ctlseqs.html#Bracketed%20Paste%20Mode)
+    // makes sure that text the user pastes is not interpreted as commands by the running program
+    // (zellij in this case)
+    // this tests makes sure the "SPLIT_RIGHT_IN_PANE_MODE" command is not interpreted as Zellij,
+    // since it's inside a bracketed paste block, while the "QUIT" command is, since it is already
+    // past the block
+    let fake_win_size = PositionAndSize {
+        columns: 121,
+        rows: 20,
+        x: 0,
+        y: 0,
+        ..Default::default()
+    };
+    let mut fake_input_output = get_fake_os_input(&fake_win_size);
+    fake_input_output.add_terminal_input(&[
+        &PANE_MODE,
+        &BRACKETED_PASTE_START,
+        &SPLIT_RIGHT_IN_PANE_MODE,
+        &BRACKETED_PASTE_END,
+        &QUIT,
+    ]);
+    start(
+        Box::new(fake_input_output.clone()),
+        CliArgs::default(),
+        Box::new(fake_input_output.clone()),
+        Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
