@@ -7,7 +7,7 @@ use crate::tests::possible_tty_inputs::Bytes;
 use crate::tests::utils::{get_next_to_last_snapshot, get_output_frame_snapshots};
 use crate::{start, CliArgs};
 
-use crate::common::input::config::Config;
+use crate::common::input::{config::Config, options::Options};
 use crate::tests::utils::commands::QUIT;
 
 /*
@@ -48,6 +48,7 @@ pub fn run_bandwhich_from_fish_shell() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -77,6 +78,7 @@ pub fn fish_tab_completion_options() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -111,6 +113,7 @@ pub fn fish_select_tab_completion_options() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -149,6 +152,7 @@ pub fn vim_scroll_region_down() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -184,6 +188,7 @@ pub fn vim_ctrl_d() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -218,6 +223,7 @@ pub fn vim_ctrl_u() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -247,6 +253,7 @@ pub fn htop() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -276,6 +283,7 @@ pub fn htop_scrolling() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -305,6 +313,7 @@ pub fn htop_right_scrolling() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -342,6 +351,7 @@ pub fn vim_overwrite() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -374,6 +384,7 @@ pub fn clear_scroll_region() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -403,6 +414,7 @@ pub fn display_tab_characters_properly() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -432,6 +444,7 @@ pub fn neovim_insert_mode() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -463,6 +476,7 @@ pub fn bash_cursor_linewrap() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -494,6 +508,7 @@ pub fn fish_paste_multiline() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -523,6 +538,7 @@ pub fn git_log() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -554,6 +570,7 @@ pub fn git_diff_scrollup() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -583,6 +600,7 @@ pub fn emacs_longbuf() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -612,6 +630,7 @@ pub fn top_and_quit() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -647,6 +666,7 @@ pub fn exa_plus_omf_theme() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
