@@ -5,10 +5,11 @@ use crate::tests::fakes::FakeInputOutput;
 use crate::tests::utils::{get_next_to_last_snapshot, get_output_frame_snapshots};
 use crate::{start, CliArgs};
 
-use crate::common::input::config::Config;
+use crate::common::input::{config::Config, options::Options};
 use crate::tests::utils::commands::{
-    MOVE_FOCUS_LEFT_IN_PANE_MODE, MOVE_FOCUS_RIGHT_IN_PANE_MODE, PANE_MODE, QUIT,
-    SPLIT_DOWN_IN_PANE_MODE, SPLIT_RIGHT_IN_PANE_MODE,
+    ENTER, MOVE_FOCUS_LEFT_IN_NORMAL_MODE, MOVE_FOCUS_LEFT_IN_PANE_MODE,
+    MOVE_FOCUS_RIGHT_IN_PANE_MODE, NEW_TAB_IN_TAB_MODE, PANE_MODE, QUIT, SPLIT_DOWN_IN_PANE_MODE,
+    SPLIT_RIGHT_IN_PANE_MODE, TAB_MODE,
 };
 
 fn get_fake_os_input(fake_win_size: &PositionAndSize) -> FakeInputOutput {
@@ -36,6 +37,7 @@ pub fn move_focus_left() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -74,6 +76,46 @@ pub fn move_focus_left_to_the_most_recently_used_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
+    );
+
+    let output_frames = fake_input_output
+        .stdout_writer
+        .output_frames
+        .lock()
+        .unwrap();
+    let snapshots = get_output_frame_snapshots(&output_frames, &fake_win_size);
+    let snapshot_before_quit =
+        get_next_to_last_snapshot(snapshots).expect("could not find snapshot");
+    assert_snapshot!(snapshot_before_quit);
+}
+
+#[test]
+pub fn move_focus_left_changes_tab() {
+    let fake_win_size = PositionAndSize {
+        columns: 121,
+        rows: 20,
+        x: 0,
+        y: 0,
+        ..Default::default()
+    };
+    let mut fake_input_output = get_fake_os_input(&fake_win_size);
+    fake_input_output.add_terminal_input(&[
+        &PANE_MODE,
+        &SPLIT_DOWN_IN_PANE_MODE,
+        &ENTER,
+        &TAB_MODE,
+        &NEW_TAB_IN_TAB_MODE,
+        &ENTER,
+        &MOVE_FOCUS_LEFT_IN_NORMAL_MODE,
+        &QUIT,
+    ]);
+    start(
+        Box::new(fake_input_output.clone()),
+        CliArgs::default(),
+        Box::new(fake_input_output.clone()),
+        Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
