@@ -5,7 +5,7 @@ use crate::tests::fakes::FakeInputOutput;
 use crate::tests::utils::{get_next_to_last_snapshot, get_output_frame_snapshots};
 use crate::{start, CliArgs};
 
-use crate::common::input::config::Config;
+use crate::common::input::{config::Config, options::Options};
 use crate::tests::utils::commands::{
     MOVE_FOCUS_IN_PANE_MODE, PANE_MODE, QUIT, RESIZE_DOWN_IN_RESIZE_MODE,
     RESIZE_LEFT_IN_RESIZE_MODE, RESIZE_MODE, SLEEP, SPLIT_DOWN_IN_PANE_MODE,
@@ -48,6 +48,7 @@ pub fn resize_down_with_pane_above() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -93,6 +94,7 @@ pub fn resize_down_with_pane_below() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -144,6 +146,7 @@ pub fn resize_down_with_panes_above_and_below() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -194,6 +197,7 @@ pub fn resize_down_with_multiple_panes_above() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -246,6 +250,7 @@ pub fn resize_down_with_panes_above_aligned_left_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -297,6 +302,7 @@ pub fn resize_down_with_panes_below_aligned_left_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -346,6 +352,7 @@ pub fn resize_down_with_panes_above_aligned_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -396,6 +403,7 @@ pub fn resize_down_with_panes_below_aligned_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -449,6 +457,7 @@ pub fn resize_down_with_panes_above_aligned_left_and_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -504,6 +513,7 @@ pub fn resize_down_with_panes_below_aligned_left_and_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -576,6 +586,7 @@ pub fn resize_down_with_panes_above_aligned_left_and_right_with_panes_to_the_lef
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -650,6 +661,7 @@ pub fn resize_down_with_panes_below_aligned_left_and_right_with_to_the_left_and_
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -692,6 +704,7 @@ pub fn cannot_resize_down_when_pane_below_is_at_minimum_height() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
