@@ -5,7 +5,7 @@ use crate::tests::fakes::FakeInputOutput;
 use crate::tests::utils::{get_next_to_last_snapshot, get_output_frame_snapshots};
 use crate::{start, CliArgs};
 
-use crate::common::input::config::Config;
+use crate::common::input::{config::Config, options::Options};
 use crate::tests::utils::commands::{
     MOVE_FOCUS_IN_PANE_MODE, PANE_MODE, QUIT, RESIZE_LEFT_IN_RESIZE_MODE, RESIZE_MODE,
     RESIZE_UP_IN_RESIZE_MODE, SLEEP, SPLIT_DOWN_IN_PANE_MODE, SPLIT_RIGHT_IN_PANE_MODE,
@@ -46,6 +46,7 @@ pub fn resize_up_with_pane_above() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -91,6 +92,7 @@ pub fn resize_up_with_pane_below() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -141,6 +143,7 @@ pub fn resize_up_with_panes_above_and_below() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -190,6 +193,7 @@ pub fn resize_up_with_multiple_panes_above() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -240,6 +244,7 @@ pub fn resize_up_with_panes_above_aligned_left_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -291,6 +296,7 @@ pub fn resize_up_with_panes_below_aligned_left_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -340,6 +346,7 @@ pub fn resize_up_with_panes_above_aligned_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -390,6 +397,7 @@ pub fn resize_up_with_panes_below_aligned_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -443,6 +451,7 @@ pub fn resize_up_with_panes_above_aligned_left_and_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -498,6 +507,7 @@ pub fn resize_up_with_panes_below_aligned_left_and_right_with_current_pane() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -570,6 +580,7 @@ pub fn resize_up_with_panes_above_aligned_left_and_right_with_panes_to_the_left_
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -644,6 +655,7 @@ pub fn resize_up_with_panes_below_aligned_left_and_right_with_to_the_left_and_ri
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
@@ -686,6 +698,7 @@ pub fn cannot_resize_up_when_pane_above_is_at_minimum_height() {
         CliArgs::default(),
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
 
     let output_frames = fake_input_output
