@@ -1,7 +1,7 @@
 use crate::panes::PositionAndSize;
 use ::insta::assert_snapshot;
 
-use crate::common::input::config::Config;
+use crate::common::input::{config::Config, options::Options};
 use crate::tests::fakes::FakeInputOutput;
 use crate::tests::utils::commands::QUIT;
 use crate::tests::utils::{get_next_to_last_snapshot, get_output_frame_snapshots};
@@ -35,6 +35,7 @@ pub fn window_width_decrease_with_one_pane() {
         opts,
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -71,6 +72,7 @@ pub fn window_width_increase_with_one_pane() {
         opts,
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -107,6 +109,7 @@ pub fn window_height_increase_with_one_pane() {
         opts,
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
@@ -143,6 +146,7 @@ pub fn window_width_and_height_decrease_with_one_pane() {
         opts,
         Box::new(fake_input_output.clone()),
         Config::default(),
+        Options::default(),
     );
     let output_frames = fake_input_output
         .stdout_writer
